==> biglybt_3.2.0.0.orig.tar.xz: BiglyBT-3.2.0.0/core/src/com/biglybt/core/util/Wiki.java <==
package com.biglybt.core.util;

import static com.biglybt.core.util.Constants.URL_WIKI;

/**
 * Holds and provides the urls all wiki pages.
 */
public interface Wiki
{
	/**
	 * Link to the main wiki page.
	 */
	String MAIN_PAGE = URL_WIKI;

	// alphabetical order from here...

	String ADVANCED_NETWORK_SETTINGS = URL_WIKI + "w/UG_Options#Advanced_Network_Settings";

	String ALL_TRACKERS_VIEW = URL_WIKI + "w/AllTrackersView";

	String AUTO_SPEED = URL_WIKI + "w/Auto_Speed";

	String APPLICATION_DISSAPEARS = URL_WIKI + "w/Vuze_disappears";

	String AVOID_TRAFFIC_SHAPING = URL_WIKI + "w/Avoid_traffic_shaping";

	String BACKUP_AND_RESTORE = URL_WIKI + "w/Backup_And_Restore";

	String COMMANDLINE_OPTIONS__CHANGING_CONTROL_PORT = URL_WIKI + "w/Commandline_options#Changing_the_Control_Port";

	String DEFINITIONS = URL_WIKI + "w/This_funny_word";

	String DEVICES_FAQ = URL_WIKI + "w/FAQ_Devices";

	String DNS = URL_WIKI + "w/UG_Options#DNS";

	String DECENTRALIZED_CHAT = URL_WIKI + "w/Decentralized_Chat";

	String DEVICES_ITUNES_TIPS = URL_WIKI + "w/Devices_iTunes_Tips";

	String DOWNLOADING_RULES = URL_WIKI + "w/Downloading_Rules";

	String FAQ_LEGAL = URL_WIKI + "w/FAQ_Legal";

	String FAILED_UPDATE = URL_WIKI + "w/Failed_Update";

	String FAT32_FILE_SIZE_LIMIT = URL_WIKI + "w/FAT32_file_size_limit";

	String FRIENDS = URL_WIKI + "w/Friends";

	String FRIENDS_PUBLIC_PROFILE = URL_WIKI + "w/Friends#public-profile";

	String GOOD_SETTINGS = URL_WIKI + "w/Good_settings";

	String HIGH_CPU_USAGE = URL_WIKI + "w/High_CPU_Usage";

	String HOSTING_FILES = URL_WIKI + "w/HostingFiles";

	String HTTP_SEEDING = URL_WIKI + "w/HTTP_Seeding";

	//todo: correct this link
	String INTERFACE_FORMAT_OVERRIDES = URL_WIKI + "w/UG_Options_Interface_Format_Overrides";

	String JAVA_VM_MEMORY_USAGE = Constants.URL_WIKI + "w/JAVA_VM_MEMORY_USAGE";

	String MODE_ADVANCED = URL_WIKI + "w/Mode#Advanced";
	String MODE_BEGINNER = URL_WIKI + "w/Mode#Beginner";
	String MODE_INTERMEDIATE = URL_WIKI + "w/Mode#Intermediate";

	String NAT_PROBLEM = URL_WIKI + "w/NAT_problem";

	String PAIRING = URL_WIKI + "w/UG_Options#Pairing";

	String PRIVACY_VIEW = URL_WIKI + "w/Privacy_View";

	String PUBLIC_PRIVATE_KEYS = URL_WIKI + "w/Public_Private_Keys";

	String PUBLISHING_FILES = URL_WIKI + "w/PublishingFiles";

	String REGULAR_EXPRESSIONS = URL_WIKI + "w/RegularExpressions";
	
	String RESTARTING_ISSUES = URL_WIKI + "w/Restarting_Issues";

	String SECURE_REMOTE_PASSWORD = URL_WIKI + "w/Secure_Remote_Password";

	String SPEED_LIMIT_SCHEDULER = URL_WIKI + "w/Speed_Limit_Scheduler";

	String SPEED_TEST_FAQ = URL_WIKI + "w/Speed_Test_FAQ";

	String SWT_CANT_AUTO_UPDATE = URL_WIKI + "w/SWT_Cant_Auto_Update";

	String UNIX_STARTUP_SCRIPT = URL_WIKI + "w/Unix_Startup_Script";

	String UPNP = URL_WIKI + "w/UPnP";

	String VERSION_AZUREUSPLATFORM = URL_WIKI + "w/Version.azureusplatform.com";

	String WHY_PORTS_LIKE_6881_ARE_NO_GOOD_CHOICE = URL_WIKI + "w/Why_ports_like_6881_are_no_good_choice";

}

==> biglybt_3.7.0.0.orig.tar.xz: BiglyBT-3.7.0.0/core/src/com/biglybt/core/util/Wiki.java <==
package com.biglybt.core.util;

import static com.biglybt.core.util.Constants.URL_WIKI;

/**
 * Holds and provides the urls all wiki pages.
 */
public interface Wiki
{
	/**
	 * Link to the main wiki page.
	 */
	String MAIN_PAGE = URL_WIKI;

	// alphabetical order from here...

	String ADVANCED_NETWORK_SETTINGS = URL_WIKI + "w/UG_Options#Advanced_Network_Settings";

	String ALL_TRACKERS_VIEW = URL_WIKI + "w/AllTrackersView";

	String AUTO_SPEED = URL_WIKI + "w/Auto_Speed";

	String APPLICATION_DISSAPEARS = URL_WIKI + "w/Vuze_disappears";

	String AVOID_TRAFFIC_SHAPING = URL_WIKI + "w/Avoid_traffic_shaping";

	String BACKUP_AND_RESTORE = URL_WIKI + "w/Backup_And_Restore";

	String COMMANDLINE_OPTIONS__CHANGING_CONTROL_PORT = URL_WIKI + "w/Commandline_options#Changing-the-Control-Port";

	String DEFINITIONS = URL_WIKI + "w/This_funny_word";

	String DEVICES_FAQ = URL_WIKI + "w/FAQ_Devices";

	String DNS = URL_WIKI + "w/UG_Options#DNS";

	String DECENTRALIZED_CHAT = URL_WIKI + "w/Decentralized_Chat";

	String DEVICES_ITUNES_TIPS = URL_WIKI + "w/Devices_iTunes_Tips";

	String DOWNLOADING_RULES = URL_WIKI + "w/Downloading_Rules";

	String FAQ_LEGAL = URL_WIKI + "w/FAQ_Legal";

	String FAILED_UPDATE = URL_WIKI + "w/Failed_Update";

	String FAT32_FILE_SIZE_LIMIT = URL_WIKI + "w/FAT32_file_size_limit";

	String FRIENDS = URL_WIKI + "w/Friends";

	String FRIENDS_PUBLIC_PROFILE = URL_WIKI + "w/Friends#public-profile";

	String GOOD_SETTINGS = URL_WIKI + "w/Good_settings";

	String HIGH_CPU_USAGE = URL_WIKI + "w/High_CPU_Usage";

	String HOSTING_FILES = URL_WIKI + "w/HostingFiles";

	String HTTP_SEEDING = URL_WIKI + "w/HTTP_Seeding";

	//todo: correct this link
	String INTERFACE_FORMAT_OVERRIDES = URL_WIKI + "w/UG_Options_Interface_Format_Overrides";

	String JAVA_VM_MEMORY_USAGE = Constants.URL_WIKI + "w/JAVA_VM_MEMORY_USAGE";

	String MODE_ADVANCED = URL_WIKI + "w/Mode#Advanced";
	String MODE_BEGINNER = URL_WIKI + "w/Mode#Beginner";
	String MODE_INTERMEDIATE = URL_WIKI + "w/Mode#Intermediate";

	String NAT_PROBLEM = URL_WIKI + "w/NAT_problem";

	String PAIRING = URL_WIKI + "w/UG_Options#Pairing";

	String PRIVACY_VIEW = URL_WIKI + "w/Privacy_View";

	String PUBLIC_PRIVATE_KEYS = URL_WIKI + "w/Public_Private_Keys";

	String PUBLISHING_FILES = URL_WIKI + "w/PublishingFiles";

	String REGULAR_EXPRESSIONS = URL_WIKI + "w/RegularExpressions";
	
	String RESTARTING_ISSUES = URL_WIKI + "w/Restarting_Issues";

	String SECURE_REMOTE_PASSWORD = URL_WIKI + "w/Secure_Remote_Password";

	String SPEED_LIMIT_SCHEDULER = URL_WIKI + "w/Speed_Limit_Scheduler";

	String SPEED_TEST_FAQ = URL_WIKI + "w/Speed_Test_FAQ";

	String SWT_CANT_AUTO_UPDATE = URL_WIKI + "w/SWT_Cant_Auto_Update";

	String UNIX_STARTUP_SCRIPT = URL_WIKI + "w/Unix_Startup_Script";

	String UPNP = URL_WIKI + "w/UPnP";

	String VERSION_AZUREUSPLATFORM = URL_WIKI + "w/Version.azureusplatform.com";

	String WHY_PORTS_LIKE_6881_ARE_NO_GOOD_CHOICE = URL_WIKI + "w/Why_ports_like_6881_are_no_good_choice";

}
